@@ -33,7 +33,7 @@ class RestClient(object):
         self.headers = {
             "Content-Type": "application/json",
             "Authorization": self.get_token_header(self.token),
-            "User-Agent": "Ximilar Client/Python"
+            "User-Agent": "Ximilar Client/Python",
         }
         self.check_resource(resource_name)
         self.request_timeout = request_timeout
@@ -152,9 +152,7 @@ class RestClient(object):
         self.invalidate()
 
         url = urllib.parse.urljoin(self.endpoint, api_endpoint)
-        result = requests.delete(
-            url, params=params, headers=self.headers, data=data, timeout=self.request_timeout
-        )
+        result = requests.delete(url, params=params, headers=self.headers, data=data, timeout=self.request_timeout)
 
         if result.status_code == HTTP_NO_CONTENT_204:
             return result
